==> rflowcyt_1.14.0.tar.gz: rflowcyt/man/fcs.type.Rd <==
\name{fcs.type}
\alias{fcs.type}
\alias{FCS.type}
\alias{fcs.type.LYSYS}
\alias{fcs.type.cellquest.3.1.FACS.Vantage}
\alias{fcs.type.cellquest.3.1.FACScan}
\alias{fcs.type.cellquest.3.3}
\alias{fcs.type.default}
\alias{fcs.type.LSR256}
\alias{fcs.type.FACStar256}
\alias{fcs.type.facscan256}
\alias{fcs.type.DiVa1024}
\alias{fcs.type.FACSCalibur1024}
\alias{fcs.type.LSR1024}
\alias{fcs.type.facscan1024}

%- Also NEED an `\alias' for EACH other topic documented here.
\title{Objects providing parameters for the raw FCS file types}

\description{
  The \code{fcs.type} objects define the parameters needed for reading
  in certain raw FCS files into R via the use of \code{\link{read.FCS}}.
  Currently this is just a script file defining certain \code{fcs.type}
  objects, but ultimately this will be an environment.  There are
  certain \code{\link{read.FCS}} parameters that are known to be
  compatible for certain types of cytometers.  The \code{fcs.type}
  objects may be optionally used during the reading in of raw FCS files
  into R and result in FCS R-objects (FCS objects).
}
\usage{
   fcs.type.default
}
\arguments{
  No arguments.
}
\details{
  A fcs.type is a list of the following:
  \item{version}{raw FCS version number; value$=$"1.0" or "2.0" or "3.0"}
  \item{byte.size}{The byte size for the file (8 bits is one byte);
    value=1 or 2 or 4, etc.}
  \item{signed}{boolean; If the data is signed; value$=$FALSE or TRUE}
  \item{endian}{The endian of the file depending on the endian of the
    platform; Usually the value of endian is "big" (if both the file and
    platform endian are "big") or "little" (if both the platform and the
    file endian are "little") or  "auto", then the read.FCS will
    automatically detect the endian compatibility with the platform
    system (See \code{\link{readBin}} for more details.)} 
  
  The fcs.types are the following:
  \item{1.  fcs.type.default}{a list of the following options and values: 
    \item{version}{"2.0"}
    \item{byte.size}{2}
    \item{signed}{TRUE}
    \item{endian}{"auto"}
  }
  \item{2.  fcs.type.cellquest.3.1.FACScan}{a list of the following options
    and values:
    \item{version}{"2.0"}
    \item{byte.size}{1}
    \item{signed}{FALSE}
    \item{endian}{"auto"}
  }
  \item{3.  fcs.type.LSR256}{a list of the following options
    and values:
    \item{version}{"2.0"}
    \item{byte.size}{1}
    \item{signed}{FALSE}
    \item{endian}{"auto"}
  }
  \item{4.  fcs.type.FACStar256}{a list of the following options
    and values:
    \item{version}{"2.0"}
    \item{byte.size}{1}
    \item{signed}{FALSE}
    \item{endian}{"auto"}
  }
  \item{5.  fcs.type.facscan256}{a list of the following options
    and values:
    \item{version}{"2.0"}
    \item{byte.size}{1}
    \item{signed}{FALSE}
    \item{endian}{"auto"}
  }
  \item{6.  fcs.type.cellquest.3.1.FACS.Vantage}{a list of the following options and values: 
    \item{version}{"2.0"}
    \item{byte.size}{2}
    \item{signed}{TRUE}
    \item{endian}{"auto"}
  }
  \item{7.  fcs.type.cellquest.3.3}{a list of the following options and values: 
    \item{version}{"2.0"}
    \item{byte.size}{2}
    \item{signed}{TRUE}
    \item{endian}{"auto"}
  }
  \item{8.  fcs.type.LYSYS}{a list of the following options and values: 
    \item{version}{"2.0"}
    \item{byte.size}{2}
    \item{signed}{TRUE}
    \item{endian}{"auto"}
  }
  \item{9.  fcs.type.DiVa1024}{a list of the following options and values: 
    \item{version}{"2.0"}
    \item{byte.size}{2}
    \item{signed}{TRUE}
    \item{endian}{"auto"}
  }
  \item{10. fcs.type.FACSCalibur1024}{a list of the following options and values: 
    \item{version}{"2.0"}
    \item{byte.size}{2}
    \item{signed}{TRUE}
    \item{endian}{"auto"}
  }
  \item{11. fcs.type.LSR1024}{a list of the following options and values: 
    \item{version}{"2.0"}
    \item{byte.size}{2}
    \item{signed}{TRUE}
    \item{endian}{"auto"}
  }
  \item{12. fcs.type.facscan1024}{a list of the following options and values: 
    \item{version}{"2.0"}
    \item{byte.size}{2}
    \item{signed}{TRUE}
    \item{endian}{"auto"}
  }
}
\value{
  With the help of fcs.type, the raw FCS file will be read into a
  FCS R object that can be implemented for further analysis in R. 
}
\references{Peter Rabinovitch}
\author{A.J. Rossini and J.Y. Wan}
\seealso{\code{\link{read.FCS}},
  \code{\link{readBin}}
}
\examples{

  if (require(rfcdmin)) {
    ## obtaining the location of the fcs files in the data
    get.path<-function(filename) {
      datadir<-system.file("fcs", package="rfcdmin")
      return(paste(datadir, filename, sep="/"))
    }



    FF256 <-read.FCS(get.path("facscan256.fcs"),
                              fcs.type=fcs.type.facscan256)
  }

}
\keyword{environment}

==> rflowcyt_1.16.0.tar.gz: rflowcyt/man/fcs.type.Rd <==
\name{fcs.type}
\alias{fcs.type}
\alias{FCS.type}
\alias{fcs.type.LYSYS}
\alias{fcs.type.cellquest.3.1.FACS.Vantage}
\alias{fcs.type.cellquest.3.1.FACScan}
\alias{fcs.type.cellquest.3.3}
\alias{fcs.type.default}
\alias{fcs.type.LSR256}
\alias{fcs.type.FACStar256}
\alias{fcs.type.facscan256}
\alias{fcs.type.DiVa1024}
\alias{fcs.type.FACSCalibur1024}
\alias{fcs.type.LSR1024}
\alias{fcs.type.facscan1024}

%- Also NEED an `\alias' for EACH other topic documented here.
\title{Objects providing parameters for the raw FCS file types}

\description{
  The \code{fcs.type} objects define the parameters needed for reading
  in certain raw FCS files into R via the use of \code{\link{read.FCS}}.
  Currently this is just a script file defining certain \code{fcs.type}
  objects, but ultimately this will be an environment.  There are
  certain \code{\link{read.FCS}} parameters that are known to be
  compatible for certain types of cytometers.  The \code{fcs.type}
  objects may be optionally used during the reading in of raw FCS files
  into R and result in FCS R-objects (FCS objects).
}
\usage{
   fcs.type.default
}
\arguments{
  No arguments.
}
\details{
  A fcs.type is a list of the following:
  \describe{
  \item{version}{raw FCS version number; value$=$"1.0" or "2.0" or "3.0"}
  \item{byte.size}{The byte size for the file (8 bits is one byte);
    value=1 or 2 or 4, etc.}
  \item{signed}{boolean; If the data is signed; value$=$FALSE or TRUE}
  \item{endian}{The endian of the file depending on the endian of the
    platform; Usually the value of endian is "big" (if both the file and
    platform endian are "big") or "little" (if both the platform and the
    file endian are "little") or  "auto", then the read.FCS will
    automatically detect the endian compatibility with the platform
    system (See \code{\link{readBin}} for more details.)} 
  }
  The fcs.types are the following:
  \describe{
  \item{1.  fcs.type.default}{a list of the following options and values: 
    \describe{
      \item{version}{"2.0"}
      \item{byte.size}{2}
      \item{signed}{TRUE}
      \item{endian}{"auto"}
    }
  } 
  
  \item{2.  fcs.type.cellquest.3.1.FACScan}{a list of the following options
    and values:
    \describe{
      \item{version}{"2.0"}
      \item{byte.size}{1}
      \item{signed}{FALSE}
      \item{endian}{"auto"}
    }
  }
  
  \item{3.  fcs.type.LSR256}{a list of the following options
    and values:
    \describe{
      \item{version}{"2.0"}
      \item{byte.size}{1}
      \item{signed}{FALSE}
      \item{endian}{"auto"}
    }
  }
  \item{4.  fcs.type.FACStar256}{a list of the following options
    and values:
    \describe{
      \item{version}{"2.0"}
      \item{byte.size}{1}
      \item{signed}{FALSE}
      \item{endian}{"auto"}
    }
  }
  \item{5.  fcs.type.facscan256}{a list of the following options
    and values:
    \describe{
      \item{version}{"2.0"}
      \item{byte.size}{1}
      \item{signed}{FALSE}
      \item{endian}{"auto"}
    }
  }
  \item{6.  fcs.type.cellquest.3.1.FACS.Vantage}{a list of the following
    options and values: 
    \describe{
    \item{version}{"2.0"}
    \item{byte.size}{2}
    \item{signed}{TRUE}
    \item{endian}{"auto"}
    }
  }
  \item{7.  fcs.type.cellquest.3.3}{a list of the following options and values: 
    \describe{
    \item{version}{"2.0"}
    \item{byte.size}{2}
    \item{signed}{TRUE}
    \item{endian}{"auto"}
    }
  }
  \item{8.  fcs.type.LYSYS}{a list of the following options and values: 
    \describe{
    \item{version}{"2.0"}
    \item{byte.size}{2}
    \item{signed}{TRUE}
    \item{endian}{"auto"}
    }
  }
  \item{9.  fcs.type.DiVa1024}{a list of the following options and values: 
    \describe{
    \item{version}{"2.0"}
    \item{byte.size}{2}
    \item{signed}{TRUE}
    \item{endian}{"auto"}
    }
  }
  \item{10. fcs.type.FACSCalibur1024}{a list of the following options and values: 
    \item{version}{"2.0"}
    \item{byte.size}{2}
    \item{signed}{TRUE}
    \item{endian}{"auto"}
  }
  \item{11. fcs.type.LSR1024}{a list of the following options and values: 
    \describe{
    \item{version}{"2.0"}
    \item{byte.size}{2}
    \item{signed}{TRUE}
    \item{endian}{"auto"}
    }
  }
  \item{12. fcs.type.facscan1024}{a list of the following options and values: 
    \describe{
    \item{version}{"2.0"}
    \item{byte.size}{2}
    \item{signed}{TRUE}
    \item{endian}{"auto"}
    }
  }
 }

}

\value{
  With the help of fcs.type, the raw FCS file will be read into a
  FCS R object that can be implemented for further analysis in R. 
}
\references{Peter Rabinovitch}
\author{A.J. Rossini and J.Y. Wan}
\seealso{\code{\link{read.FCS}},
  \code{\link{readBin}}
}
\examples{

  if (require(rfcdmin)) {
    ## obtaining the location of the fcs files in the data
    get.path<-function(filename) {
      datadir<-system.file("fcs", package="rfcdmin")
      return(paste(datadir, filename, sep="/"))
    }



    FF256 <-read.FCS(get.path("facscan256.fcs"),
                              fcs.type=fcs.type.facscan256)
  }

}
\keyword{environment}
